@@ -1,16 +1,42 @@
 from importlib import import_module
 from pkgutil import iter_modules
+from functools import lru_cache
+from importlib.util import spec_from_file_location
+from importlib.util import module_from_spec
 
-from . import debug
+from pybrary.func import fqn
+from pybrary.files import find
+
+from . import debug, error
 import setux.core
 from .distro import Distro
 
 
+@lru_cache()
 def get_modules(ns):
+    debug(f'{ns.__name__}')
     path, name = ns.__path__, ns.__name__ + '.'
-    debug(f'{path} {name}')
-    for finder, name, _ispkg in iter_modules(path, name):
-        yield name, import_module(name)
+    try:
+        # namespace
+        found = list()
+        for pth in path._path:
+            debug(f'    {pth}')
+            for fil in find(pth, r'\.py$'):
+                if fil.name=='__init__.py':
+                    error(f' ! __init__ in ns {pth}')
+                    break
+                nam = name+fil.stem
+                spec = spec_from_file_location(nam, fil)
+                mod = module_from_spec(spec)
+                spec.loader.exec_module(mod)
+                found.append((nam, mod))
+        return found
+    except Exception as x:
+        # package
+        return [
+            (name, import_module(name))
+            for finder, name, _ispkg in iter_modules(path, name)
+        ]
 
 
 def get_raw_plugins(ns, cls):
@@ -52,9 +78,10 @@ class Plugins:
         for mod, plg, plugin in plugins:
             key, val = self.parse(mod, plg, plugin)
             if key and val:
-                debug(f'{val.__module__}.{val.__name__} registered')
                 self.items[key] = val
         self.sort()
+        for mod in self.items.values():
+            debug('%s registred', fqn(mod))
 
 
 class Managers(Plugins):
